Client API Reference
====================


This section offers an in-depth description of SpeckleClient API calls.

The :class:`SpeckleClient` class
--------------------------------

.. automodule:: speckle.base.client
   :members:


Accounts Methods
----------------
.. automodule:: speckle.resources.accounts
   :members:


Projects Methods
----------------
.. automodule:: speckle.resources.projects
   :members:


Streams Methods
---------------
.. automodule:: speckle.resources.streams
   :members:


Api Client Methods
-------------------
.. automodule:: speckle.resources.api_clients
   :members:


Comments methods
-----------------
.. automodule:: speckle.resources.comments
   :members:


Objects Methods
---------------
.. automodule:: speckle.resources.objects
   :members:

